      PROGRAM MIXER


C     BY A.K. COKER

C     A.K.C TECHNOLOGY 2013.
 


C	THIS PROGRAM WILL CALCULATE THE HEAT TRANSFER COEFFICIENT TO FLUIDS
C	IN VESSELS WITH MECHANICAL AGITATION HEATED OR COOLED BY EITHER
C	SUBMERGED TUBE COILS OR THE JACKETED VESSEL.

C	*******************************************************************

C	HTRC	=   HEAT-TRANSFER COEFFICIENT, Btu/hr.ft^2.oF, W/m^2.K.
C	DV	=   DIAMETER OF VESSEL, ft., m.
C	TC	=   THERMAL CONDUCTIVITY, Btu/hr.ft.oF., W/m.K.
C	L	=   DIAMETER OF AGITATOR, ft., m.
C	N	=   SPEED OF AGITATOR IN REVOLUTION PER MIN.
C	RHO	=   DENSITY OF FLUID., lb/ft.^3, kg/m^3.
C	VIS	=   VISCOSITY OF FLUID, cP, Pa (N.s/m^2.).
C	SHC	=   SPECIFIC HEAT CAPACITY, Btu/lb.oF., kJ/kg.K.
C	VISB	=   VISCOSITY AT BULK FLUID TEMPERATURE, cP, (N.s/m^2).
C	VISW	=   VISCOSITY AT SURFACE TEMPARTURE, cP, (N.s/m^2).


C	********************************************************************

	CHARACTER*12 CHX, SURF

	LOGICAL ISTURB, ISPADD, ISANCH, ISPROP
	LOGICAL ISCOIL, ISJACK


	INTEGER CHOICE
	REAL N, L

	OPEN (UNIT = 3, FILE = 'DATAV.DAT', STATUS='OLD', ERR=18)
	
	OPEN (UNIT = 1, FILE = 'MIXER.RES')
	
	
	READ (3, *, ERR=19) CHOICE
	READ (3, 10, ERR=19) CHX
	READ (3, 20, ERR=19) SURF

 10	FORMAT (A)

 20	FORMAT (A)


	READ (3, *, ERR=19) DV, TC, L, N
	READ (3, *, ERR=19) RHO, VIS, SHC, VISB
	READ (3, *, ERR=19) VISW



C	AGITATOR	    SURFACE		    A
C	*********************************************************************
C	TURBINE 	    JACKET		    0.62
C	TURBINE 	    COIL		    1.50
C	PADDLE		    JACKET		    0.36
C	PADDLE		    COIL		    0.87
C	ANCHOR		    JACKET		    0.46
C	PROPELLER	    JACKET		    0.54
C	PROPELLER	    COIL		    0.83
C	*********************************************************************


	GO TO 30

 18	WRITE (1, 100)
 100	FORMAT (5X, 'FILE DOES NOT EXIST')

	GO TO 999

 19	WRITE (1, 110)
 110	FORMAT (5X, 'ERROR MESSAGE IN THE DATA VALUE')

	GO TO 999


 30	WRITE (1, 120)
 120	FORMAT(/, 15X,'HEAT TRANSFER COEFFICIENT TO FLUIDS IN A VESSEL')

	WRITE (1, 130)
 130	FORMAT (15X, 'USING MECHANICAL AGITATED COILS OR JACKET',/,
     *	       78(1H*))



 	WRITE (*, 140)
 140	FORMAT(/, 15X,'HEAT TRANSFER COEFFICIENT TO FLUIDS IN A VESSEL')

	WRITE (*, 150)
 150	FORMAT (15X, 'USING MECHANICAL AGITATED COILS OR JACKET',/,
     *	      780(1H*))




	CALL UPPER (CHX)

	CALL UPPER (SURF)

	ISTURB	=   CHX .EQ. 'TURBINE'

	ISPADD	=   CHX .EQ. 'PADDLE'

	ISANCH	=   CHX .EQ. 'ANCHOR'

	ISPROP	=   CHX .EQ. 'PROPELLER'

	ISJACK	=   SURF .EQ. 'JACKET'

	ISCOIL	=   SURF .EQ. 'COIL'


	IF (ISTURB  .AND.   ISJACK) THEN
	A = 0.62

	ELSE IF (ISTURB .AND.	ISCOIL) THEN
	A = 1.50

	ELSE IF (ISPADD .AND.	ISJACK) THEN
	A = 0.36

	ELSE IF (ISPADD .AND.	ISCOIL) THEN
	A = 0.87

	ELSE IF (ISANCH .AND.	ISJACK) THEN
	A = 0.46

	ELSE IF (ISPROP .AND.	ISJACK) THEN
	A = 0.54

	ELSE IF (ISPROP .AND.	ISCOIL) THEN
	A = 0.83

	ELSE

	WRITE (*, *) 'ERROR MESSAGE IN THE IF STATEMENTS'

	ENDIF

	IF (CHOICE .EQ. 1) THEN

C	CALCULATE THE THE HEAT TRANSFER COEFFICIENT USING IMPERIAL UNITS.


C	CALCULATE THE DIMENSIONLESS NUMBERS, REYNOLDS AND PRANDTL NUMBERS


	RE  =(L **2 * N * RHO * 60.0) / (VIS * 2.42)

	RE1  =RE**(2.0/3.0)

	PR  =(SHC * VIS * 2.42) / TC

	PR1  =PR**(1.0/3.0)

	RATIO=  VISB / VISW

C	CALCULATE THE HEAT TRANSFER COEFFICIENT, HTRC Btu/hr.ft^2.

	HTRC =  (A * TC * RE1 * PR1 * RATIO) / DV


	write (1, 160) CHX, SURF
 160	FORMAT (5X, 'AGITATOR:', T50, A, /
     *		5X, 'SURFACE:', T50, A)


	WRITE (1, 170) A, DV, TC, L, N
 170	FORMAT (5X,  'VALUE OF A:', T50, F8.3,/,
     *		5X,  'DIAMETER OF VESSEL, ft.:', T50, F10.3,/,
     *		5X, 'THERMAL CONDUCTIVITY, Btu/hr.ft.oF.:',T50,F10.3,/,
     *		5X, 'DIAMETER OF AGITATOR, ft.:', T50, F10.3,/,
     *		5X, 'SPEED OF AGITATOR, rev/min.:', T50, F10.3)


	WRITE (1, 180) RHO, VIS, SHC, VISB, VISW
 180	FORMAT (5X, 'DENSITY  OF FLUID, lb/ft^3:', T50, F10.3,/,
     *	5X, 'VISCOSITY OF FLUID, cP:', T50, F10.3,/,
     *	5X, 'SPECIFIC HEAT CAPACITY, Btu/lb.oF:', T50, F10.3,/,
     *	5X, 'VISCOSITY AT BULK FLUID TEMPERATURE, cP:', T50, F10.3,/,
     *	5X, 'VISCOSITY AT SURFACE TEMPERATURE, cP:', T50, F10.3)

	WRITE (1, 190) RE, PR, HTRC
 190	FORMAT (5X, 'REYNOLDS NUMBER:', T50, F12.0,/,
     *	5X, 'PRANDTL NUMBER:', T50, F12.3,/,
     *	5X, 'HEAT TRANSFER COEFFICIENT, Btu/hr.ft^2.oF:', T50, F12.3)


	write (*, 200) CHX, SURF
 200	FORMAT (5X, 'AGITATOR:', T60, A, /
     *		5X, 'SURFACE:', T60, A)


	WRITE (*, 210) A, DV, TC, L, N
 210	FORMAT (5X,  'VALUE OF A:', T60, F8.3,/,
     *		5X,  'DIAMETER OF VESSEL, ft.:', T60, F10.3,/,
     *		5X, 'THERMAL CONDUCTIVITY, Btu/hr.ft.oF.:',T60,F10.3,/,
     *		5X, 'DIAMETER OF AGITATOR, ft.:', T60, F10.3,/,
     *		5X, 'SPEED OF AGITATOR, rev/min.:', T60, F10.3)


	WRITE (*, 220) RHO, VIS, SHC, VISB, VISW
 220	FORMAT (5X, 'DENSITY  OF FLUID, lb/ft^3:', T60, F10.3,/,
     *	5X, 'VISCOSITY OF FLUID, cP:', T60, F10.3,/,
     *	5X, 'SPECIFIC HEAT CAPACITY, Btu/lb.oF:', T60, F10.3,/,
     *	5X, 'VISCOSITY AT BULK FLUID TEMPERATURE, cP:', T60, F10.3,/,
     *	5X, 'VISCOSITY AT SURFACE TEMPERATURE, cP:', T60, F10.3)


	WRITE (*, 230) RE, PR, HTRC
 230	FORMAT (5X, 'REYNOLDS NUMBER:', T60, F12.0,/,
     *	5X, 'PRANDTL NUMBER:', T60, F12.3,/,
     *	5X, 'HEAT TRANSFER COEFFICIENT, Btu/hr.ft^2.oF:', T60, F12.3)



	GO TO 40

	ELSEIF (CHOICE .EQ. 2) THEN


C	CALCULATE THE THE HEAT TRANSFER COEFFICIENT USING S.I. UNITS.


C	CALCULATE THE DIMENSIONLESS NUMBERS, REYNOLDS AND PRANDTL NUMBERS


	RE = (L **2 * N * RHO) / (60.0 * VIS * 0.001)

	RE1 = RE**(2.0/3.0)

	PR  = (SHC * VIS) / TC

	PR1  = PR**(1.0/3.0)

	RATIO=  VISB / VISW

C	CALCULATE THE HEAT TRANSFER COEFFICIENT, HTRC W/m^2.K.

	HTRC =  (A * TC * RE1 * PR1 * RATIO) / DV

	ENDIF

	write (1, 235) CHX, SURF
 235	FORMAT (5X, 'AGITATOR:', T60, A, /
     *		5X, 'SURFACE:', T60, A)

	WRITE (1, 240) A, DV, TC, L, N
 240	FORMAT (5X,  'VALUE OF A:', T50, F8.3,/,
     *		5X,  'DIAMETER OF VESSEL, m.:', T50, F10.3,/,
     *		5X, 'THERMAL CONDUCTIVITY, W/m.K.:',T50,F10.3,/,
     *		5X, 'DIAMETER OF AGITATOR, m.:', T50, F10.3,/,
     *		5X, 'SPEED OF AGITATOR, rev/min.:', T50, F10.3)

	WRITE (1, 250) RHO, VIS, SHC, VISB, VISW
 250	FORMAT (5X, 'DENSITY  OF FLUID, kg/m^3:', T50, F10.3,/,
     *	5X, 'VISCOSITY OF FLUID, Pa.s:', T50, F10.3,/,
     *	5X, 'SPECIFIC HEAT CAPACITY, kJ/kg.K:', T50, F10.3,/,
     *	5X, 'VISCOSITY AT BULK FLUID TEMPERATURE, Pa.s:', T50, F10.3,/,
     *	5X, 'VISCOSITY AT SURFACE TEMPERATURE, Pa.s:', T50, F10.3)

	WRITE (1, 300) RE, PR, HTRC
 300	FORMAT (5X, 'REYNOLDS NUMBER:', T50, F12.0,/,
     *	5X, 'PRANDTL NUMBER:', T50, F12.3,/,
     *	5X, 'HEAT TRANSFER COEFFICIENT, W/m^2.K.:', T50, F12.3)

	write (*, 305) CHX, SURF
305	FORMAT (5X, 'AGITATOR:', T60, A, /
     *		5X, 'SURFACE:', T60, A)

	WRITE (*, 310) A, DV, TC, L, N
 310	FORMAT (5X,  'VALUE OF A:', T60, F8.3,/,
     *		5X,  'DIAMETER OF VESSEL, m.:', T60, F10.3,/,
     *		5X, 'THERMAL CONDUCTIVITY, W/m.K.:',T60,F10.3,/,
     *		5X, 'DIAMETER OF AGITATOR, m.:', T60, F10.3,/,
     *		5X, 'SPEED OF AGITATOR, rev/min.:', T60, F10.3)

	WRITE (*, 320) RHO, VIS, SHC, VISB, VISW
 320	FORMAT (5X, 'DENSITY  OF FLUID, kg/m^3:', T60, F10.3,/,
     *	5X, 'VISCOSITY OF FLUID, Pa.s:', T60, F10.3,/,
     *	5X, 'SPECIFIC HEAT CAPACITY, kJ/kg.K:', T60, F10.3,/,
     *	5X, 'VISCOSITY AT BULK FLUID TEMPERATURE, Pa.s:', T60, F10.3,/,
     *	5X, 'VISCOSITY AT SURFACE TEMPERATURE, Pa.s:', T60, F10.3)


	WRITE (*, 330) RE, PR, HTRC
 330	FORMAT (5X, 'REYNOLDS NUMBER:', T60, F12.0,/,
     *	5X, 'PRANDTL NUMBER:', T60, F12.3,/,
     *	5X, 'HEAT TRANSFER COEFFICIENT, W/m^2.K.:', T60, F12.3)

  40	continue

	write (1, 340)
 340	format (78(1h-))


	WRITE (*, 350)
 350	FORMAT (78(1H-))	
	

	CLOSE (3, STATUS = 'KEEP')
	CLOSE (1)

 999	STOP
	END

C	THIS PROGRAM TAKES CARE OF THE LOWER CASE CONDITIONS.

	SUBROUTINE UPPER (AA)

	CHARACTER*(*) AA

	LENGTH = LEN_TRIM(AA)

	DO 10 I = 1, LENGTH

	N = ICHAR (AA(I:I))

	IF (N .GE. 97 .AND. N .LE. 122) N = N-32

	AA (I:I) = CHAR(N)

 10	CONTINUE

	RETURN

	END
