	PROGRAM PROG153

C	BY A.K. COKER
C	A.K.C. TECHNOLOGY 2015
C	U.K. 

C	********************************************************************
C	THIS PROGRAM RATES DOUBLE PIPE HEAT EXCHANGERS USING
C	BARE TUBES OR LONGITUDINAL FINNED TUBES.
C	THE PROGRAM CALCULATES THE HEAT LOAD, THE LOG MEAN TEMPERATURE
C	DIFFERENCE FOR COUNTER CURRENT FLOW, THE CORRECTED FILM HEAT TRANSFER
C	COEFFICIENTS IN BOTH THE TUBE AND THE SHELL SIDES, THE OVERALL HEAT
C	TRANSFER COEFFICIENT AND THE HEAT TRANSFER SURFACE. THE PROGRAM
C	FURTHER CALCULATES THE FRICTION FACTOR (Using correlations given by
C	Dennis Wright: Basic Programs for chemical engineers, Van Nostrand
C	Reinhold Company, NY 1986) AND THE PRESSURE DROP IN THE TUBE AND THE
C	SHELL SIDES OF THE DOUBLE PIPE HEAT EXCHANGERS.
C	********************************************************************
C	HI	         = HEAT-TRANSFER FILM COEFFICIENT, Btu/ft^2 oF.h
C	K	         = FLUID THERMAL CONDUCTIVITY, Btu/ft.h.oF
C	RE	         =  REYNOLDS NUMBER
C	PR	       	 = PRANDTL NUMBER
C	DEQ	         = EQUIVALENT DIAMETER, ft.
C	VIS	         = FLUID VISCOSITY (FLOWING), cP.
C	VISW		 = FLUID VISCOSITY (AT WALL), cP.
C	VIST	         = FLUID VISCOSITY (TUBE SIDE), cP.
C	VISS       	 = FLUID VISCOSITY (SHELL SIDE - bare tube), cP.
C	VISF	         = FLUID VISCOSITY (SHELL SIDE - finned tube), cP.
C	J	         = HEAT-TRANSFER FACTOR
C	G	         = MASS FLOW RATE, lb/h.ft^2.
C	CP	         = FLUID SPECIFIC HEAT, Btu/lb.oF.
C	AREA		 = HEAT TRANSFER SURFACE AREA, ft^2.
C	IDT	         = INSIDE-TUBE DIAMETER, in.
C	IDF	         = INSIDE DIAMETER (finned tube), in.
C	FOL	       	 = FOULING FACTOR
C	HIF	         = HEAT-TRANSFER FILM COEFFICIENT CORRECTED
C		           FOR FOULING, Btu/ft^2.oF.h.
C	IDS	        = INSIDE SHELL DIAMETER, in.
C	ODT	        = OUTSIDE TUBE DIAMETER, in.
C	DELTW		= TUBE WALL THICKNESS, ft.
C	KT	        = THERMAL CONDUCTIVITY OF TUBE MATERIAL, Btu/ft.h.oF.
C	AI	        = INSIDE HEAT-TRANSFER AREA-TUBE, ft^2/ft.
C	AO	        = OUTSIDE HEAT-TRANSFER AREA-TUBE, ft^2/ft (FOR FINNED
C		            TUBES INCLUDES FIN AREA).
C	UO	        = OVERALL HEAT-TRANSFER COEFFICIENT, Btu/h.ft^2.oF.
C	NFA	        = NET FREE CROSS-SECTIONAL AREA, SHELL SIDE, ft^2.
C	AF	        = FINNED TRANSFER AREA, ft^2 .
C	X	        = PARAMETER USED IN FIN EFFICIENCY CALCULATION
C	FE	        = FIN EFFICIENCY (%).
C	ESEF	        = EFFECTIVE SURFACE EFFICIENCY FOR FINS (%).
C	HIFD  		= CORRECTED FILM HEAT-TRANSFER RATE, Btu/ft^2.h.oF
C	TDEN		= TUBE SIDE FLUID DENSITY, lb/ft^3.
C	SDEN		= SHELL SIDE FLUID DENSITY, lb/ft^3.
C       SPEC      	= SPECIFIC GRAVITY (DENSITY OF FLUID/DENSITY OF WATER)
C	NTP	        = NUMBER OF TUBE PASSES.
C	NSP   		= NUMBER OF SHELL PASSES (bare-tube).
C	NFP	        = NUMBER OF SHELL PASSES (finned-tube).
C	FOLT      	= FOULING FACTOR OF THE TUBE SIDE.
C	FOLS	        = FOULING FACTOR OF THE SHELL SIDE (bare-tube).
C	FOLF	        = FOULING FACTOR OF THE SHELL SIDE (finned-tube).
C	FTTUBE		= FLUID NAME IN THE TUBE SIDE.
C	FTSHELL 	= FLUID NAME IN THE SHELL SIDE
C	FLUIDT		= FLUID PHASE FLOW IN THE TUBE SIDE.
C	FLUIDS		= FLUID PHASE FLOW IN THE SHELL SIDE.
C	TUBE		= CHECKS TO DETERMINE WHETHER THE DOUBLE PIPE HEAT
C		           EXCHANGER IS BARE-TUBED OR FINNED-TUBE.
C	LMTD		= LOG MEAN TEMPERATURE DIFFERENCE (oF).
C	TL	        = TUBE LENGTH, ft.
C	WT	        = FLUID FLOWRATE TUBE SIDE, lb/hr.
C	WS	        = FLUID FLOWRATE SHELL SIDE (BARE-TUBE), lb/hr.
C	WF	        = FLUID FLOWRATE SHELL SIDE (FINNED-TUBE), lb/hr.
C	***************************************************************

	CHARACTER*30 FLUIDT, FLUIDS, FLUIDF, TUBE, FTTUBE, FTSHELL
	EXTERNAL HTFCV,HTFCL,HTFCJ

	REAL IDTF, IDSF, IDFF, ODTF, ODSF, ODFF
	REAL IDT,ODT,KT
	REAL IDS,ODS,KS,KST
	REAL IDF,ODF,KF,KFT
	REAL LMTD

	COMMON TUBE
	COMMON/DATA/FTTUBE, FTSHELL, TDEN, SDEN, SPEC
	COMMON/DATA1/FLUIDT,IDT,ODT,WT,CPT,VIST,KT,TT1,TT2,FOLT,TL,NTP
	COMMON/DATA2/FLUIDS,IDS,ODS,WS,CPS,VISS,KS,TS1,TS2,FOLS,KST,NSP
	COMMON/DATA3/FLUIDF,IDF,ODF,WF,CPF,VISF,KF,TF1,TF2,FOLF,
     *	FHT,FTHICK,NF,KFT,NFP
	COMMON/DATA4/ PI
	COMMON/DATA5/ IDTF, IDSF, IDFF, ODTF, ODSF, ODFF

	COMMON/RES1/VELT,RET,PRT,FRICTT,DROPT,HTFT,HIFTU
	COMMON/RES2/VELS,RES,PRS,FRICTS,DROPS,HTFS,HIFS
	COMMON/RES3/VELF,REF,PRF,FRICTF,DROPF,HTFF,HIFF,X,FE,ESEF,HIFD,
     *	UO

	COMMON/RES4/ LMTD, AREA, Q
	COMMON/RES5/DROPRN, TOTDROP

	OPEN(UNIT=3,FILE='DATA153.DAT',STATUS='OLD',ACTION='READ',
     *	ERR=18)


	OPEN (UNIT= 1, FILE='res153.res')

	PI = 3.1415927


C	TUBE-SIDE HEAT-TRANSFER CALCULATIONS

C	INPUT NAME OF FLUID IN THE TUBE SIDE

	READ (3, 9, ERR=19) FTTUBE
 9	FORMAT (A)

C	INPUT FLUID PHASE FLOW (e.g. liquid/vapor)

	READ (3, 11, ERR=19) FLUIDT
 11	FORMAT (A)


C	READ THE INSIDE TUBE DIAMETER, inch.: IDT
C	READ THE OUTSIDE TUBE DIAMETER, inch.: ODT
C	READ THE FLUID FLOWRATE IN THE TUBE SIDE, lb/hr.: WT
C	READ THE FLUID SPECIFIC HEAT CAPACITY, Btu/lb.oF.: CPT
C	READ THE FLUID VISCOSITY, cP: VIST
C	READ THE FLUID THERMAL CONDUCTIVITY, KT: Btu/hr.ft.oF: KT
C	READ THE FLUID INLET TEMPERATURE, oF: TT1
C	READ THE FLUID OUTLET TEMPERATURE, oF: TT2
C	READ THE TUBE SIDE FOULING FACTOR: FOLT
C	READ THE TUBE SIDE FLUID DENSITY, lb/ft^3: TDEN
C	READ THE TUBE LENGTH, ft.: TL
C	READ THE NUMBER OF TUBE PASSES: NTP


	READ (3, *, ERR=19) IDT, ODT, WT
	READ (3, *, ERR=19) CPT, VIST, KT
	READ (3, *, ERR=19) TT1, TT2, FOLT
	READ (3, *, ERR=19) TDEN, TL, NTP
	READ(3,  *, ERR=19) SPEC
	GO TO 10


C	CHECK WHETHER THE HEAT EXCHANGER IS BARE-TUBE OR FINNED-TUBE
C	i.e., WHETHER THE HEAT EXCHANGER HAS FINS

C	INPUT NAME OF FLUID IN THE SHELL SIDE

 5	READ (3, 14, ERR=19) FTSHELL
 14	FORMAT (A)


	READ (3, 22, ERR=19) TUBE
 22	FORMAT (A)

	IF (TUBE .EQ. 'FINS' .OR. TUBE .EQ. 'fins') THEN


	GO TO 33
	ELSEIF (TUBE .EQ. 'BARE-TUBE'.OR. TUBE .EQ. 'bare-tube') THEN

C	READ DATA VALUES FOR THE SHELL-SIDE BARE-TUBE


C	INPUT FLUID PHASE FLOW (e.g. liquid/vapor)

	READ (3, 34, ERR=19) FLUIDS
 34	FORMAT(A)

C	READ THE INSIDE DIAMETER, inch.: IDS
C	READ THE OUTSIDE DIAMETER, inch.: ODS
C	READ THE FLUID FLOWRATE, lb/hr.: WS
C	READ THE FLUID SPECIFIC HEAT CAPACITY, Btu/lb.oF: CPS
C	READ THE FLUID VISCOSITY, cP.: VISS
C	READ THE FLUID THERMAL CONDUCTIVITY, Btu/ft.hr.oF: KS
C	READ THE FLUID INLET TEMPERATURE, oF: TS1
C	READ THE FLUID OUTLET TEMPERATURE, oF: TS2
C	READ THE SHELL SIDE FOULING FACTOR: FOLS
C	READ THE TUBE THERMAL CONDUCTIVITY, Btu/ft.hr.oF: KST
C	READ THE FLUID DENSITY, lb/ft^3.: SDEN
C	READ THE NUMBER OF SHELL PASSES: NSP


	READ (3, *, ERR=19) IDS, ODS, WS
	READ (3, *, ERR=19) CPS, VISS, KS
	READ (3, *, ERR=19) TS1, TS2, FOLS
	READ (3, *, ERR=19) KST, SDEN, NSP

	ENDIF

C	CALCULATE THE LOG MEAN TEMPERATURE DIFFERENCE, LMTD (oF)

	CALL LOGMTD (TS1, TS2, TT1, TT2, LMTD)

	GO TO 20

C	READ DATA VALUES FOR THE SHELL-SIDE FINNED TUBE

C	INPUT PHASE FLOW OF FLUID IN THE SHELL SIDE (e.g. Liquid/vapor)

 33	READ (3, 44, ERR=19) FLUIDF
 44	FORMAT (A)


C	READ THE NUMBER OF FINS: NF
C	READ THE INSIDE DIAMETER, inch.: IDF
C	READ THE OUTSIDE DIAMETER, inch.: ODF
C	READ THE FLUID FLOWRATE, lb/hr.: WF
C	READ THE FLUID SPECIFIC HEAT, Btu/lb.oF: CPF
C	READ THE FLUID VISCOSITY, cP.: VISF
C	READ THE FLUID THERMAL CONDUCTIVITY, Btu/hr.ft.oF: KF
C	READ THE FLUID INLET TEMPERATURE, oF: TF1
C	READ THE FLUID OUTLET TEMPERATURE, oF: TF2
C	READ THE FLUID FOULING FACTOR: FOLF
C	READ THE FINS HEIGHT, inch.: FHT
C	READ THE FINS THICHNESS, inch.: FTHICK
C	READ THE TUBE SIDE THERMAL CONDUCTIVITY, Btu/hr.ft.oF: KFT
C	READ THE FLUID DENSITY, lb/ft^3: SDEN
C	READ THE NUMBER OF PASSES: NFP


	READ (3, *, ERR=19) NF
	READ (3, *, ERR=19) IDF, ODF, WF
	READ (3, *, ERR=19) CPF, VISF, KF
	READ (3, *, ERR=19) TF1, TF2, FOLF
	READ (3, *, ERR=19) FHT, FTHICK
	READ (3, *, ERR=19) KFT, SDEN, NFP


C	CALCULATE THE LOG MEAN TEMPERATURE DIFFERENCE, LMTD (oF)

	CALL LOGMTD (TF1, TF2, TT1, TT2, LMTD)

C	CALCULATE THE HEAT LOAD ON UNIT, Btu/hr.

	Q = WF*CPF*(TF1-TF2)

C	SHELL-SIDE CALCULATIONS (FINNED-TUBE)


	GO TO 30

 18	WRITE (*, 100)
 100	FORMAT(//,6X,'DATA FILE DOES NOT EXIST')
	GO TO 999

 19	WRITE (*, 110)
 110	FORMAT(//,6X,'ERROR MESSAGE IN THE DATA VALUE')
	GO TO 999

C	TUBE-SIDE CALCULATIONS

 10	CALL PROG1
	GO TO 5

C	SHELL-SIDE CALCULATIONS (BARE-TUBE)

 20	CALL PROG2

	GO TO 40

C	SHELL-SIDE CALCULATIONS (FINNED-TUBE)

 30	CALL PROG3


C	CALCULATE THE HEAT TRANSFER SURFACE AREA, (AREA, ft^2).

 40	AREA = Q/(UO*LMTD)


	CALL RESULTS

	CALL SCREEN


	CLOSE (3, STATUS='KEEP')
	CLOSE (1)

 999	STOP
	END

C      *****************************************************************
C	PROGRAM CALCULATES HEAT-TRANSFER FILM COEFFICIENT IN THE TUBE
C	SIDE HEAT EXCHANGER
C	*****************************************************************

	SUBROUTINE PROG1

	CHARACTER*30 FLUIDT, FTTUBE, FTSHELL,FLUIDF

	REAL IDT, ODT, KT
	REAL IDTF, IDSF, IDFF, ODTF, ODSF, ODFF
	REAL IDF, ODF, KF, KFT

	COMMON/DATA/FTTUBE, FTSHELL, TDEN, SDEN, SPEC
	COMMON/DATA1/FLUIDT,IDT,ODT,WT,CPT,VIST,KT,TT1,TT2,FOLT,TL,NTP
	COMMON/DATA3/FLUIDF,IDF,ODF,WF,CPF,VISF,KF,TF1,TF2,FOLF,
     *	FHT,FTHICK,NF,KFT,NFP
	COMMON/DATA4/PI
	COMMON/DATA5/IDTF, IDSF, IDFF, ODTF, ODSF, ODFF

	COMMON/RES1/VELT,RET,PRT,FRICTT,DROPT,HTFT,HIFTU

        COMMON/RES5/DROPRN, TOTDROP

        
        IDTF = IDT/12.0
	ODTF = ODT/12.0
	DEQT = IDTF

C	CALCULATE THE CROSS-SECTIONAL AREA OF TUBE

	AT = (PI*IDTF**2)/4.0

C	CALCULATE THE MASS VELOCITY, lb/ft^2.hr.

	GT = WT/AT

C	CALCULATE THE FLUID VELOCITY, ft./sec.

	VELT = GT/(3600.0*TDEN)

C	CALCULATE THE REYNOLDS NUMBER

	RET = (GT*DEQT)/(2.42*VIST)

C	CALCULATE THE PRANDTL NUMBER

	PRT = (CPT*2.42*VIST)/KT


C	CALCULATE THE FRICTION FACTOR (Dennis Wright: Basic Programs
C	for chemical engineers: Van Nostrand Reinhold Company, NY 1986).

	IF (RET .GT. 2100.0) THEN

	FRICTT = 0.0035 + 0.264/(RET**0.42)
	ELSEIF (RET .LT. 2100.0 ) THEN
	FRICTT = 16/RET
	ENDIF

C	CALCULATE THE PRESSURE DROP

C	DROPT = (4.0*FRICTT*TL*NTP*(GT/3600.0)**2)/(64.4*TDEN*DEQT)

	DROPT= (4*FRICTT *TDEN *VELT**2*TL)/(2.0* 32.174*144.0*DEQT)


        DROPRN = (4 * NTP *TDEN* VELT**2)/(2 * 32.174 * 144.0)

	TOTDROP = DROPT + DROPRN

C	WRITE (*, 222) DROPT, DROPRN, TOTDROP
C222  FORMAT (2X, 'DROPT=', F9.3, 3X, 'DROPRN=', F9.3, 3X, 'TOTDROP=',
C    *    F9.3)
 
C	CHECK WHETHER FLUID IN THE TUBE SIDE IS LIQUID OR VAPOR.

	IF (FLUIDT .EQ. 'LIQUID'.OR. FLUIDT .EQ. 'liquid') THEN
	GO TO 30
	ELSEIF (FLUIDT .EQ. 'VAPOR' .OR. FLUIDT .EQ. 'vapor') THEN

C	CALCULATE THE HEAT-TRANSFER FILM COEFFICIENT IN THE VAPOR STATE

	HTFT = HTFCV (CPT,GT,DEQT)
	ENDIF

	GO TO 90

 30	IF(RET .LT. 2100.0) THEN
	GO TO 50
	ELSE
	HTFT = HTFCL (RET,PRT,KT,DEQT)
	ENDIF

	GO TO 90


 50	HTFT = HTFCJ (RET, PRT, KT, DEQT, TL)


C	CALCULATE THE HEAT-TRANSFER FILM COEFFICIENT CORRECTED FOR
C	FOULING, Btu/hr.ft^2.oF

 90	HIFTU = HTFT/(1.0+HTFT*FOLT)

	RETURN
	END

C	****************************************************************
C	PROGRAM CALCULATES HEAT-TRANSFER FILM COEFFICIENT IN THE SHELL
C	SIDE (BARE-TUBE) AND THE OVERALL HEAT TRANSFER COEFFICIENT OF
C	THE HEAT EXCHANGER
C	****************************************************************

	SUBROUTINE PROG2

	CHARACTER*30  FLUIDS, FLUIDT, FTSHELL,FTTUBE
	REAL IDS, IDT, ODS, ODT, KS, KT
	REAL IDTF, IDSF, IDFF, ODTF, ODSF, ODFF
	REAL LMTD

	COMMON/DATA/FTTUBE, FTSHELL, TDEN, SDEN, SPEC
	COMMON/DATA1/FLUIDT,IDT,ODT,WT,CPT,VIST,KT,TT1,TT2,FOLT,TL,NTP
	COMMON/DATA2/FLUIDS,IDS,ODS,WS,CPS,VISS,KS,TS1,TS2,FOLS,KST,NSP
	COMMON/DATA4/PI
	COMMON/DATA5/IDTF, IDSF, IDFF, ODTF, ODSF, ODFF

	COMMON/RES1/VELT,RET,PRT,FRICTT,DROPT,HTFT,HIFTU
	COMMON/RES2/VELS,RES,PRS,FRICTS,DROPS,HTFS,HIFS

	COMMON/RES4/LMTD, AREA, Q

	IDSF = IDS/12.0
	ODSF = ODS/12.0
	DEQS = IDSF-ODTF
	RATIO1 = IDT/ODT

C	CALCULATE THE CROSS-SECTIONAL AREA

	AS = (PI*IDSF**2)/4.0

C	CALCULATE THE MASS VELOCITY, Ib/ft^2.hr.

	GS = WS/AS

C	CALCULATE THE FLUID VELOCITY, ft./sec.

	VELS = GS/(3600.0*SDEN)

C	CALCULATE THE REYNOLDS NUMBER

	RES = (GS*DEQS)/(2.42*VISS)

C	WRITE (*, 100) AS, WS, GS
C100  FORMAT (3X, 'AS=', F9.2, 3X, 'WS=', F12.2, 3X, 'GS=', F12.2)

C	WRITE (*, 105) DEQS, VISS, RES
C105  FORMAT(3X, 'DEQS=', F9.3, 3X, 'VISS=', F9.4, 3X, 'RES=', F12.2)

C	CALCULATE THE PRANDTL NUMBER

	PRS = (CPS*2.42*VISS)/KS

C	CALCULATE THE FRICTION FACTOR (Dennis Wright: Basic Programs for
C	chemical engineers, Van Nostrand Reinhold Company, NY 1986.)

C	CALCULATE THE FRICTION FACTOR

	CALL FFACTOR (RES, FRICTS)


C	CALCULATE THE PRESSURE DROP, psi.

	CALL PDROP (FRICTS, TL, NSP, GS, SDEN, DEQS, DROPS)


	IF (FLUIDS .EQ. 'LIQUID' .OR. FLUIDS .EQ. 'liquid') THEN

	GO TO 30

	ELSEIF (FLUIDS .EQ. 'VAPOR' .OR. FLUIDS .EQ. 'vapor') THEN

C	CALCULATE THE HEAT TRANSFER FILM COEFFICIENT IN THE VAPOR STATE

	HTFS = HTFCV(CPS,GS,DEQS)
	ENDIF

	GO TO 90


 30	IF (RES .LT. 2100.0) THEN
	GO TO 50
	ELSE
	HTFS = HTFCL (RES,PRS,KS,DEQS)
	ENDIF
	GO TO 90


 50	HTFS = HTFCJ (RES, PRS, KS, DEQS, TL)

C	CALCULATE THE HEAT-TRANSFER FILM COEFFICIENT CORRECTED
C	FOR FOULING.

 90	HIFS = HTFS/(1.0+HTFS*FOLS)

C	CALCULATE THE OVERALL HEAT TRANSFER COEFFICIENT.

	DELTW = (ODT/12.)-(IDT/12.0)
	RATIO2 = (DELTW/KST)+(1.0/(HIFTU*RATIO1))+(1.0/HIFS)
	UO = 1.0/RATIO2

	RETURN
	END

C	****************************************************************
C	PROGRAM CALCULATES HEAT-TRANSFER FILM COEFFICIENT IN THE
C	SHELL SIDE (FINNED-TUBE) AND THE OVERALL HEAT TRANSFER
C	COEFFICIENT OF THE HEAT EXCHANGER.
C	*****************************************************************

	SUBROUTINE PROG3

	CHARACTER*30 FLUIDT,FLUIDF,FTSHELL,FTTUBE


	REAL IDF,ODF,KF,KFT,KT,NFA,IDT,ODT
	REAL IDTF, IDSF, IDFF, ODTF, ODSF, ODFF

	COMMON/DATA/FTTUBE, FTSHELL, TDEN, SDEN, SPEC
	COMMON/DATA1/FLUIDT,IDT,ODT,WT,CPT,VIST,KT,TT1,TT2,FOLT,TL,NTP
	COMMON/DATA3/FLUIDF,IDF,ODF,WF,CPF,VISF,KF,TF1,TF2,FOLF,
     *	FHT,FTHICK,NF,KFT,NFP
	COMMON/DATA4/PI
	COMMON/DATA5/IDTF, IDSF, IDFF, ODTF, ODSF, ODFF

	COMMON/RES3/VELF,REF,PRF,FRICTF,DROPF,HTFF,HIFF,X,FE,ESEF,HIFD,
     *	UO

	IDFF = IDF/12.0
	ODFF = ODF/12.0
	ODTF = ODT/12.0
	AF = (2.0*FHT*FLOAT(NF))/12.0
	AO = (PI*ODTF)/12.0+AF

C	WRITE (*, 52) IDFF, ODFF, ODTF
C 52	FORMAT (3X, 'IDFF=', F9.3, 3X, 'ODFF=', F9.3, 3X, 'ODTF=', F9.3)	
C	WRITE (*, 53) AF, AO
C53	FORMAT (3X,'AF=', F9.3, 3X, 'AO=', F9.3)


C	CALCULATE CROSS-SECTIONAL AREA, SHELL SIDE WITHOUT FINS, ft^2.

	CSA = (PI*(IDFF**2-ODTF**2))/4.0

C	CALCULATE NET FREE CROSS-SECTIONAL AREA, SHELL SIDE, ft^2.

	NFA = CSA-(FHT*FTHICK*FLOAT(NF))/144.0

C	CALCULATE THE CROSS-SECTIONAL AREA.

	CAF = (PI*IDFF**2)/4.0

C	CALCULATE THE MASS VELOCITY, lb/ft^2.hr.

	GF = WF/NFA

C	CALCULATE THE FLUID VELOCITY, ft./sec.

	VELF = GF/(3600.0*SDEN)

C	CALCULATE THE WETTED PERIMETER.

	DENOM = (PI*(IDFF+ODTF))-(FTHICK*FLOAT(NF))/12.0+AF
	DEQF = (4.0*NFA)/DENOM

C	CALCULATE THE REYNOLDS NUMBER

	REF = (GF*DEQF)/(2.42*VISF)

C	WRITE (*, 100) NFA, WF, GF
C100  FORMAT (3X, 'NFA=', F9.2, 3X, 'WF=', F12.2, 3X, 'GF=', F12.2)

C	WRITE (*, 105) DEQF, VISF, REF
C105  FORMAT(3X, 'DEQF=', F9.3, 3X, 'VISF=', F9.4, 3X, 'REF=', F12.2)

C	PAUSE	

C	CALCULATE THE PRANDTL NUMBER

	PRF = (CPF*2.42*VISF)/KF

C	CALCULATE THE FRICTION FACTOR

	CALL FFACTOR (REF, FRICTF)

C	CALCULATE THE PRESSURE DROP

	CALL PDROP (FRICTF, TL, NFP, GF, SPEC, DEQF, DROPF)

C	CHECK WHETHER THE FLUID IN THE SHELL SIDE IS LIQUID OR VAPOR.

	IF(FLUIDF .EQ. 'LIQUID' .OR. FLUIDF .EQ. 'liquid') THEN

	GO TO 30

	ELSEIF (FLUIDF .EQ. 'VAPOR' .OR. FLUIDF .EQ. 'vapor') THEN

C	CALCULATE THE HEAT-TRANSFER FILM COEFFICIENT IN THE VAPOR STATE.

	HTFF = HTFCV (CPF, GF, DEQF)
	ENDIF

	GO TO 90

 30	IF ( REF .LT. 2100.0) THEN
	GO TO 50
	ELSE
	HTFF = HTFCL (REF, PRF, KF, DEQF)
	
C	WRITE (*, 200) HTFF
C200  FORMAT (3X, 'HTFF=', F10.3)

C	PAUSE
	
	ENDIF
	GO TO 90

 50	HTFF = HTFCJ (REF, PRF, KF, DEQF, TL)

C	CALCULATE THE HEAT-TRANSFER FILM COEFFICIENT CORRECTED
C	FOR FOULING.

 90	HIFF = HTFF/(1.0+HTFF*FOLF)

C	CALCULATE THE OVERALL HEAT-TRANSFER COEFFICIENT.

C	CALCULATE THE PARAMETER X, USED IN THE FIN EFFICIENCY

	X =(FHT/12.0)*(HIFF/(6.0*KFT*FTHICK/12.0))**0.5

C	CALCULATE THE FIN EFFICIENCY

	VAL1 = EXP(X)-EXP(-X)
	VAL2 = EXP(X)+EXP(-X)
	FE = (1.0/X*(VAL1/VAL2))

C	CALCULATE THE EFFECTIVE SURFACE EFFICIENCY FOR FINS
	ESEF = FE*(AF/AO)+(1.0-AF/AO)

C	CALCULATE THE CORRECTED FILM HEAT TRANSFER RATE

	HIFD = HIFF*ESEF

C	CONVERT THE FIN EFFICIENCY AND EFFECTIVE SURFACE EFFICIENCY
C	TO PERCENTAGES.

	FE = 100.0*FE
	ESEF = 100.0*ESEF

C	WRITE (*, 110) X, FE
C110  FORMAT (3X,'X=', F9.3,  3X, 'FE=', F9.3)

C	WRITE (*, 115) ESEF, HIFD
C115  FORMAT (3X, 'ESEF=', F9.3, 3X, 'HIFD=', F9.3)	

C	CALCULATE OVERALL HEAT TRANSFER COEFFICIENT.

	DELTW = (ODT/12.0)-(IDT/12.0)
	RATIO3 = (PI*IDT)/((PI*ODT)+AF)
	RATIO4 = (DELTW/KFT)+(1.0/(HIFF*RATIO3))+(1.0/HIFD)
	UO = 1.0/RATIO4

C	WRITE (*, 300) UO
C300	 FORMAT (3X, 'UO=', F9.3)	
	
        RETURN
	END
C
C	*****************************************************************
C	THIS PROGRAM CALCULATES THE LOG MEAN TEMPERATURE DIFFERENCE,
C	LMTD (oF)
C	*****************************************************************

	SUBROUTINE LOGMTD (TH1, TH2, TC1, TC2, LMTD)
	REAL LMTD

	DELT1 = TH1 - TC2
	DELT2 = TH2 - TC1
	LMTD = ABS((DELT1 - DELT2)/ALOG (DELT1/DELT2))

	RETURN
	END

C	*****************************************************************
C	THIS SUBPROGRAM EVALUATES THE HEAT TRANSFER FILM COEFFICIENT
C	IN THE VAPOR STATE OF A DOUBLE PIPE HEAT EXCHANGER.
C	******************************************************************

	FUNCTION HTFCV (CP1, G1, DEQ1)

	HTFCV = (0.0144*CP1*(G1**0.8))/(DEQ1**0.2)

	RETURN
	END

C	*****************************************************************
C	THIS SUBPROGRAM EVALUATES THE HEAT TRANSFER FILM COEFFICIENT
C	IN THE LIQUID STATE OF A DOUBLE PIPE HEAT EXCHANGER.
C	*****************************************************************

	FUNCTION HTFCL (RE1, PR1, K1, D1)

	REAL K1
	HTFCL = 0.023*(RE1**0.8)*(PR1**0.333)*(K1/D1)*1.0

	RETURN
	END

C	*****************************************************************
C	THIS SUBPROGRAM EVALUATES THE HEAT TRANSFER FILM COEFFICIENT
C	FOR REYNOLDS NUMBER LESS THAN 2100.0 OF A DOUBLE PIPE
C	HEAT EXCHANGER
C	*****************************************************************

	FUNCTION HTFCJ (RE, PR, K1, D1, TL1)

	REAL K1

	HTFCJ = 1.86*(RE**0.333)*(PR**0.333)*(K1/D1)*(D1/TL1)**0.333

	RETURN
	END
C
C	******************************************************************
C	CALCULATE THE FRICTION FACTOR IN THE SHELL SIDE OF THE DOUBLE
C	PIPE HEAT EXCHANGER  (Dennis Wright: Basic Programs for chemical
C	engineers, Van Nostrand Reinhold company, NY 1986)
C	******************************************************************

	SUBROUTINE FFACTOR (RE, FACTOR)

	IF (RE .GT. 2100) THEN

	FACTOR = 0.0035 + 0.264 /(RE**0.42)

	ELSEIF (RE .LT. 2100) THEN

	FACTOR = 16.0/RE
	ENDIF
	RETURN
	END

C	*****************************************************************
C	THIS PROGRAM CALCULATES THE PRESSURE DROP FOR THE SHELL SIDE OF
C	A DOUBLE PIPE HEAT EXCHANGER
C	*****************************************************************

	SUBROUTINE PDROP (FRICT, TLEN, NP, G, SPC, EQDIA, DROP)

C	DROP = (4*FRICT*TLEN*NP*(G/3600.0)**2)/(64.4*DEN*EQDIA)


	DROP = (FRICT *TLEN*NP*G**2)/(5.22*(10**10)*SPC*EQDIA)

	RETURN
	END

C	*******************************************************************
C	THIS PROGRAM PRINTS THE RESULTS OF THE DOUBLE PIPE HEAT EXCHANGERS
C	*******************************************************************

	SUBROUTINE RESULTS

	CHARACTER*30 FLUIDT, FLUIDS, FLUIDF, TUBE, FTTUBE, FTSHELL

	REAL IDTF, IDSF, IDFF, ODTF, ODSF, ODFF
	REAL IDT, ODT, KT
	REAL IDS, ODS, KS, KST
	REAL IDF, ODF, KF, KFT
	REAL LMTD

	COMMON TUBE
	COMMON/DATA/FTTUBE, FTSHELL, TDEN, SDEN, SPEC
	COMMON/DATA1/FLUIDT,IDT,ODT,WT,CPT,VIST,KT,TT1,TT2,FOLT,TL,NTP
	COMMON/DATA2/FLUIDS,IDS,ODS,WS,CPS,VISS,KS,TS1,TS2,FOLS,KST,NSP
	COMMON/DATA3/FLUIDF,IDF,ODF,WF,CPF,VISF,KF,TF1,TF2,FOLF,
     *		     FHT,FTHICK,NF,KFT,NFP
	COMMON/DATA4/PI
	COMMON/DATA5/IDTF,IDSF,IDFF,ODTF,ODSF,ODFF

	COMMON/RES1/VELT,RET,PRT,FRICTT,DROPT,HTFT,HIFTU
	COMMON/RES2/VELS,RES,PRS,FRICTS,DROPS,HTFS,HIFS
	COMMON/RES3/VELF,REF,PRF,FRICTF,DROPF,HTFF,HIFF,X,FE,ESEF,HIFD,
     *UO
	COMMON/RES4/LMTD,AREA,Q

        COMMON/RES5/DROPRN, TOTDROP

	WRITE (1, 120)
 120	FORMAT (/,18X,'DOUBLE PIPE HEAT EXCHANGER RATING',/,18X,
     *		'USING BARE-TUBES/LONGITUDINAL FINNED TUBES'/,18X,
     *		'FORCED CONVECTION WITH NO CHANGE OF PHASE')

	WRITE (1, 130)
 130	FORMAT (1H ,78(1H*))

	WRITE (1, 140)
 140	FORMAT (45X,'TUBE SIDE', 10X, 'SHELL SIDE')

	WRITE (1, 150)
 150	FORMAT (78(1H-))

	WRITE (1, 160) FTTUBE, FTSHELL
 160	FORMAT (2X,'FLUID NAME:', T50, A15, T65, A15)

	IF (TUBE .EQ. 'FINS' .OR. TUBE .EQ. 'fins') THEN

	WRITE (1, 170) FLUIDT, FLUIDF
 170	FORMAT (2X,'TYPE OF PHASE FLOW:', T50, A15, T65, A15)

	WRITE (1, 180) WT, WF
 180	FORMAT (2X,'FLUID FLOW RATE, lb/hr.:', T45, F10.0, T60, F10.0)

	WRITE (1, 190) CPT, CPF
 190	FORMAT (2X,'SPECIFIC HEAT CAPACITY, Btu/Ib.oF:', T45, F8.3,
     *		T60, F8.3)

	WRITE (1, 200) TDEN, SDEN
 200	FORMAT (2X,'FLUID DENSITY, lb/ft^3.:', T45, F8.3, T60, F8.3)
 
 	WRITE (1, 205) SPEC
205	FORMAT (2X, 'SPECIFIC GRAVITY:', T45, F9.3)


	WRITE (1, 210) VIST, VISF
 210	FORMAT (2X,'FLUID VISCOSITY, cP:', T45, F8.3, T60, F8.3)

	WRITE (1, 220) KT, KF
 220	FORMAT (2X,'FLUID THERMAL COND., Btu/Ib.oF:', T45, F8.3,
     *		T60, F8.3)

	WRITE (1, 230) TT1, TF1
 230	FORMAT (2X,'FLUID INLET TEMPERATURE, oF:', T45, F8.3,
     *		T60, F8.3)

	WRITE (1, 240) TT2, TF2
 240	FORMAT (2X,'FLUID OUTLET TEMPERATURE, oF:', T45, F8.3,
     *		T60, F8.3)

	WRITE (1, 250) IDT, IDF
 250	FORMAT (2X,'INSIDE DIAMETER, inch:', T45, F8.3, T60, F8.3)

	WRITE (1, 260) ODT, ODF
 260	FORMAT (2X,'OUTSIDE DIAMETER, inch:', T45, F8.3, T60, F8.3)

	WRITE (1, 270) FOLT, FOLF
 270	FORMAT (2X,'FOULING FACTOR:', T45, F8.3, T60, F8.3)

	WRITE (1, 280) NTP, NFP
 280  FORMAT (2X,'NUMBER OF PASSES:', T48, I2, T63, I2)	


	WRITE (1, 285) TL
 285	FORMAT (2X,'TUBE LENGTH, ft.:', T45, F8.3)

	WRITE (1, 290) NF, FHT, FTHICK
 290	FORMAT (2X, 'NUMBER OF FINS:', T48, I2,/,
     *		2X,'FIN HEIGHT, inch:', T45, F8.3,/,
     *		2X,'FIN THICKNESS, inch:', T45, F8.3)

	WRITE (1, 300) KFT
 300	FORMAT (2X,'THERMAL COND. TUBE MATERIAL, Btu/hr.ft.oF:',
     *		T45,F8.3)

	WRITE (1, 310) VELT, VELF
 310	FORMAT (2X,'FLUID VELOCITY, ft/sec.:', T45, F8.3, T60, F8.3)

	WRITE (1, 320) RET, REF
 320	FORMAT (2X,'REYNOLDS NUMBER:', T45, F9.0, T60, F9.0)

	WRITE (1, 330) PRT, PRF
 330	FORMAT (2X,'PRANDTL NUMBER:', T45, F8.4, T60, F8.3)

	WRITE (1, 340) FRICTT, FRICTF
 340	FORMAT (2X,'FRICTION FACTOR (ft^2/in^2):', T45, F8.6, T60, F8.6)

	WRITE (1, 350) DROPT 
350	FORMAT (2X,'PRESSURE DROP, psi.:', T45, F9.3)

	WRITE (1, 355) DROPRN
355   FORMAT (2X,'RETURN LOSSES PRESSURE DROP, psi:', T45, F9.3)

	WRITE (1, 359) TOTDROP 
 359	FORMAT (2X,'TOTAL PRESSURE DROP, psi:', T45, F9.3)	

	WRITE (1, 360) X, FE, ESEF
 360	FORMAT (2X,'FIN MODULUS:', T45, F8.3,/,
     *		2X,'FIN EFFICIENCY, %:', T45, F8.3,/,
     *		2X,'EFFECTIVE SURFACE EFFICIENCY, %:', T45, F8.3)

	WRITE (1, 370) LMTD
 370	FORMAT (2X,'LOG MEAN TEMP. DIFF., oF:', T45, F8.2)


	WRITE (1, 375) HTFT, HTFF
375   FORMAT (2X,'HEAT TRANSFER FILM COEFF., Btu/h.ft^2oF:',
     *                 T45, F9.2, T60, F9.2)	

	WRITE (1, 380) HIFTU, HIFF
 380	FORMAT (2X,'HEAT TRANSFER FILM COEFF. CORRECTED',/,2X,
     *		'FOR FOULING:, Btu/hr.ft^2.oF:', T45, F9.2, T60, F9.2)

	WRITE (1, 390) UO
 390	FORMAT (2X,'OVERALL HEAT TRANSFER COEFF., Btu/hr.ft^2.oF:',
     *		T45, F9.2)

	WRITE (1, 400) Q, AREA
 400	FORMAT (2X,'HEAT LOAD ON UNIT, Btu/hr.:', T45, F12.1,/,
     *		2X,'HEAT TRANSFER SURFACE ft^2.:', T45, F8.3)

	ELSEIF (TUBE .EQ. 'BARE-TUBE' .OR. TUBE .EQ. 'bare-tube') THEN

	WRITE (1, 410) FLUIDT, FLUIDS
 410	FORMAT (2X,'TYPE OF PHASE FLOW:', T45, A15, T60, A15)

	WRITE (1, 420) WT, WS
 420	FORMAT (2X,'FLUID FLOWRATE:, lb/hr.:', T45, F10.0, T60, F10.0)

	WRITE (1, 430) CPT, CPS
 430	FORMAT (2X,'SPECIFIC HEAT CAPACITY, Btu/lb.oF:', T45, F8.3,T60,
     *		F8.3)

	WRITE (1, 440) TDEN, SDEN
 440	FORMAT (2X,'FLUID DENSITY, lb/ft^3:', T45, F8.3, T60, F8.3)

	WRITE (1, 450) VIST, VISS
 450	FORMAT (2X,'FLUID VISCOSITY, cP:', T45, F8.3, T60, F8.3)

	WRITE (1, 460) KT, KS
 460	FORMAT (2X,'FLUID THERMAL COND., Btu/Ib.oF:', T45, F8.3,
     *		T60, F8.3)

	WRITE (1, 470) TT1, TS1
 470	FORMAT (2X,'FLUID INLET TEMPERATURE, oF:',T45, F8.3, T60, F8.3)

	WRITE (1, 480) TT2, TS2
 480	FORMAT (2X,'FLUID OUTLET TEMPERATURE, oF:',T40, F8.3,T60,F8.3)

	WRITE (1, 490) IDT, IDS
 490	FORMAT (2X,'INSIDE DIAMETER, inch:',T45, F8.3, T60, F8.3)

	WRITE (1, 500) ODT, ODS
 500	FORMAT (2X,'OUTSIDE DIAMETER, inch:', T45, F8.3, T60, F8.3)

	WRITE (1, 510) FOLT, FOLS
 510	FORMAT (2X,'FOULING FACTOR:', T45, F8.3, T60, F8.3)

	WRITE (1, 520) KFT
 520	FORMAT (2X,'THERMAL COND. TUBE MATERIAL, Btu/hr.ft.oF:',
     *		T45, F8.3)

	WRITE (1, 530) VELT, VELS
 530	FORMAT (2X,'FLUID VELOCITY, ft/sec.:', T45, F8.3, T60, F8.3)

	WRITE (1, 540) RET, RES
 540	FORMAT (2X,'REYNOLDS NUMBER:', T45, F9.0, T60, F9.0)

	WRITE (1, 550) PRT, PRS
 550	FORMAT (2X,'PRANDTL NUMBER:', T45, F8.3, T60, F8.3)

	WRITE (1, 560) FRICTT, FRICTS
 560	FORMAT (2X,' FRICTION FACTOR (ft^2/in^2):', T45, F8.5,T60,F8.5)

	WRITE (1, 570) DROPT
 570	FORMAT (2X,'PRESSURE DROP, psi:', T45, F9.3)
 
 	WRITE (1, 575) DROPRN
 575  FORMAT (2X,'RETURN LOSSES PRESSURE DROP, psi:', T45, F9.3)


	WRITE (1, 580) LMTD
 580	FORMAT (2X,'LOG MEAN TEMP. DIFF., oF:', T45, F8.2)

	WRITE (1, 590) HIFTU, HIFS
 590	FORMAT (2X,'HEAT TRANSFER FILM COEFF. CORRECTED',/,2X,
     *		'FOR FOULING:, Btu/hr.ft^2.oF:', T45, F9.2, T60, F9.2)

	WRITE (1, 600) UO
 600	FORMAT (2X,'OVERALL HEAT TRANSFER FILM COEFF., Btu/hr.ft^2.oF:',
     *		T45, F9.2)

	WRITE (1, 610) Q, AREA
 610	FORMAT (2X,'HEAT LOAD ON UNIT , Btu/hr.:', T45, F12.1,/,
     *		2X,'HEAT TRANSFER SURFACE, ft^2.:', T45, F8.3)

	ENDIF

	WRITE (1, 620)
 620	FORMAT (1H ,78(1H-))

C	FORM FEED THE PRINTING PAPER TO TOP OF THE NEXT PAGE.

C	WRITE (1, *) CHAR(12)

	RETURN
	END
	
	
	SUBROUTINE SCREEN
	
	CHARACTER*30 FLUIDT, FLUIDS, FLUIDF, TUBE, FTTUBE, FTSHELL

	REAL IDTF, IDSF, IDFF, ODTF, ODSF, ODFF
	REAL IDT, ODT, KT
	REAL IDS, ODS, KS, KST
	REAL IDF, ODF, KF, KFT
	REAL LMTD

	COMMON TUBE
	COMMON/DATA/FTTUBE, FTSHELL, TDEN, SDEN, SPEC
	COMMON/DATA1/FLUIDT,IDT,ODT,WT,CPT,VIST,KT,TT1,TT2,FOLT,TL,NTP
	COMMON/DATA2/FLUIDS,IDS,ODS,WS,CPS,VISS,KS,TS1,TS2,FOLS,KST,NSP
	COMMON/DATA3/FLUIDF,IDF,ODF,WF,CPF,VISF,KF,TF1,TF2,FOLF,
     *		     FHT,FTHICK,NF,KFT,NFP
	COMMON/DATA4/PI
	COMMON/DATA5/IDTF,IDSF,IDFF,ODTF,ODSF,ODFF

	COMMON/RES1/VELT,RET,PRT,FRICTT,DROPT,HTFT,HIFTU
	COMMON/RES2/VELS,RES,PRS,FRICTS,DROPS,HTFS,HIFS
	COMMON/RES3/VELF,REF,PRF,FRICTF,DROPF,HTFF,HIFF,X,FE,ESEF,HIFD,
     *UO
	COMMON/RES4/LMTD,AREA,Q

       COMMON/RES5/DROPRN, TOTDROP

	WRITE (*, 120)
 120	FORMAT (/,18X,'DOUBLE PIPE HEAT EXCHANGER RATING',/,18X,
     *		'USING BARE-TUBES/LONGITUDINAL FINNED TUBES'/,18X,
     *		'FORCED CONVECTION WITH NO CHANGE OF PHASE')

	WRITE (*, 130)
 130	FORMAT (1H ,78(1H*))

	WRITE (*, 140)
 140	FORMAT (45X,'TUBE SIDE', 10X, 'SHELL SIDE')

	WRITE (*, 150)
 150	FORMAT (78(1H-))

	WRITE (*, 160) FTTUBE, FTSHELL
 160	FORMAT (2X,'FLUID NAME:', T50, A15, T65, A15)

	IF (TUBE .EQ. 'FINS' .OR. TUBE .EQ. 'fins') THEN

	WRITE (*, 170) FLUIDT, FLUIDF
 170	FORMAT (2X,'TYPE OF PHASE FLOW:', T50, A15, T65, A15)

	WRITE (*, 180) WT, WF
 180	FORMAT (2X,'FLUID FLOW RATE, lb/hr.:', T45, F10.0, T60, F10.0)

	WRITE (*, 190) CPT, CPF
 190	FORMAT (2X,'SPECIFIC HEAT CAPACITY, Btu/Ib.oF:', T45, F8.3,
     *		T60, F8.3)

	WRITE (*, 200) TDEN, SDEN
 200	FORMAT (2X,'FLUID DENSITY, lb/ft^3.:', T45, F8.3, T60, F8.3)

	WRITE (*, 205) SPEC
205	FORMAT (2X, 'SPECIFIC GRAVITY:', T45, F9.3)

	WRITE (*, 210) VIST, VISF
 210	FORMAT (2X,'FLUID VISCOSITY, cP:', T45, F8.3, T60, F8.3)

	WRITE (*, 220) KT, KF
 220	FORMAT (2X,'FLUID THERMAL COND., Btu/Ib.oF:', T45, F8.3,
     *		T60, F8.3)

	WRITE (*, 230) TT1, TF1
 230	FORMAT (2X,'FLUID INLET TEMPERATURE, oF:', T45, F8.3,
     *		T60, F8.3)

	WRITE (*, 240) TT2, TF2
 240	FORMAT (2X,'FLUID OUTLET TEMPERATURE, oF:', T45, F8.3,
     *		T60, F8.3)

	WRITE (*, 250) IDT, IDF
 250	FORMAT (2X,'INSIDE DIAMETER, inch:', T45, F8.3, T60, F8.3)

	WRITE (*, 260) ODT, ODF
 260	FORMAT (2X,'OUTSIDE DIAMETER, inch:', T45, F8.3, T60, F8.3)

	WRITE (*, 270) FOLT, FOLF
 270	FORMAT (2X,'FOULING FACTOR:', T45, F8.3, T60, F8.3)

	WRITE (* , 280) NTP, NFP
 280  FORMAT (2X,'NUMBER OF PASSES:', T48, I2, T63, I2)	

	WRITE (*, 285) TL
 285	FORMAT (2X,'TUBE LENGTH, ft.:', T45, F8.3)

	WRITE (*, 290) NF, FHT, FTHICK
 290	FORMAT (2X, 'NUMBER OF FINS:', T48, I2,/,
     *		2X,'FIN HEIGHT, inch:', T45, F8.3,/,
     *		2X,'FIN THICKNESS, inch:', T45, F8.3)

	WRITE (*, 300) KFT
 300	FORMAT (2X,'THERMAL COND. TUBE MATERIAL, Btu/hr.ft.oF:',
     *		T45,F8.3)

	WRITE (*, 310) VELT, VELF
 310	FORMAT (2X,'FLUID VELOCITY, ft/sec.:', T45, F8.3, T60, F8.3)

	WRITE (*, 320) RET, REF
 320	FORMAT (2X,'REYNOLDS NUMBER:', T45, F9.0, T60, F9.0)

	WRITE (*, 330) PRT, PRF
 330	FORMAT (2X,'PRANDTL NUMBER:', T45, F8.4, T60, F8.3)

	WRITE (*, 340) FRICTT, FRICTF
 340	FORMAT (2X,'FRICTION FACTOR (ft^2/in^2):', T45, F8.6, T60, F8.6)

	WRITE (*, 350) DROPT 
 350	FORMAT (2X,'PRESSURE DROP, psi.:', T45, F8.4)
 
 	WRITE (*, 355) DROPRN
 355  FORMAT (2X,'RETURN LOSSES PRESSURE DROP, psi:', T45, F9.3)
	
 	WRITE (*, 359) TOTDROP 
 359	FORMAT (2X,'TOTAL PRESSURE DROP, psi:', T45, F9.3)	

 
	WRITE (*, 360) X, FE, ESEF
 360	FORMAT (2X,'FIN MODULUS:', T45, F8.3,/,
     *		2X,'FIN EFFICIENCY, %:', T45, F8.3,/,
     *		2X,'EFFECTIVE SURFACE EFFICIENCY, %:', T45, F8.3)

	WRITE (*, 370) LMTD
 370	FORMAT (2X,'LOG MEAN TEMP. DIFF., oF:', T45, F8.2)

	WRITE (*, 375) HTFT, HTFF
375   FORMAT (2X,'HEAT TRANSFER FILM COEFF., Btu/h.ft^2oF:',
     *                 T45, F9.2, T60, F9.2)	


	WRITE (*, 380) HIFTU, HIFF
 380	FORMAT (2X,'HEAT TRANSFER FILM COEFF. CORRECTED',/,2X,
     *		'FOR FOULING:, Btu/hr.ft^2.oF:', T45, F9.2, T60, F9.2)

	WRITE (*, 390) UO
 390	FORMAT (2X,'OVERALL HEAT TRANSFER COEFF., Btu/hr.ft^2.oF:',
     *		T45, F9.2)

	WRITE (*, 400) Q, AREA
 400	FORMAT (2X,'HEAT LOAD ON UNIT, Btu/hr.:', T45, F12.1,/,
     *		2X,'HEAT TRANSFER SURFACE ft^2.:', T45, F8.3)

	ELSEIF (TUBE .EQ. 'BARE-TUBE' .OR. TUBE .EQ. 'bare-tube') THEN

	WRITE (*, 410) FLUIDT, FLUIDS
 410	FORMAT (2X,'TYPE OF PHASE FLOW:', T45, A15, T60, A15)

	WRITE (*, 420) WT, WS
 420	FORMAT (2X,'FLUID FLOWRATE:, lb/hr.:', T45, F10.0, T60, F10.0)

	WRITE (*, 430) CPT, CPS
 430	FORMAT (2X,'SPECIFIC HEAT CAPACITY, Btu/lb.oF:', T45, F8.3,T60,
     *		F8.3)

	WRITE (*, 440) TDEN, SDEN
 440	FORMAT (2X,'FLUID DENSITY, lb/ft^3:', T45, F8.3, T60, F8.3)

	WRITE (*, 450) VIST, VISS
 450	FORMAT (2X,'FLUID VISCOSITY, cP:', T45, F8.3, T60, F8.3)

	WRITE (*, 460) KT, KS
 460	FORMAT (2X,'FLUID THERMAL COND., Btu/Ib.oF:', T45, F8.3,
     *		T60, F8.3)

	WRITE (*, 470) TT1, TS1
 470	FORMAT (2X,'FLUID INLET TEMPERATURE, oF:',T45, F8.3, T60, F8.3)

	WRITE (*, 480) TT2, TS2
 480	FORMAT (2X,'FLUID OUTLET TEMPERATURE, oF:',T40, F8.3,T60,F8.3)

	WRITE (*, 490) IDT, IDS
 490	FORMAT (2X,'INSIDE DIAMETER, inch:',T45, F8.3, T60, F8.3)

	WRITE (*, 500) ODT, ODS
 500	FORMAT (2X,'OUTSIDE DIAMETER, inch:', T45, F8.3, T60, F8.3)

	WRITE (*, 510) FOLT, FOLS
 510	FORMAT (2X,'FOULING FACTOR:', T45, F8.3, T60, F8.3)

	WRITE (*, 520) KFT
 520	FORMAT (2X,'THERMAL COND. TUBE MATERIAL, Btu/hr.ft.oF:',
     *		T45, F8.3)

	WRITE (*, 530) VELT, VELS
 530	FORMAT (2X,'FLUID VELOCITY, ft/sec.:', T45, F8.3, T60, F8.3)

	WRITE (*, 540) RET, RES
 540	FORMAT (2X,'REYNOLDS NUMBER:', T45, F9.0, T60, F9.0)

	WRITE (*, 550) PRT, PRS
 550	FORMAT (2X,'PRANDTL NUMBER:', T45, F8.3, T60, F8.3)

	WRITE (*, 560) FRICTT, FRICTS
 560	FORMAT (2X,' FRICTION FACTOR (ft^2/in^2):', T45, F8.5,T60,F8.5)

	WRITE (*, 570) DROPT
 570	FORMAT (2X,'PRESSURE DROP, psi:', T45, F9.3)

	WRITE (*, 575) DROPRN
 575  FORMAT (2X,'RETURN LOSSES PRESSURE DROP, psi:', T45, F9.3)
	
	WRITE (*, 580) LMTD
 580	FORMAT (2X,'LOG MEAN TEMP. DIFF., oF:', T45, F8.2)

	WRITE (*, 590) HIFTU, HIFS
 590	FORMAT (2X,'HEAT TRANSFER FILM COEFF. CORRECTED',/,2X,
     *		'FOR FOULING:, Btu/hr.ft^2.oF:', T45, F9.2, T60, F9.2)

	WRITE (*, 600) UO
 600	FORMAT (2X,'OVERALL HEAT TRANSFER FILM COEFF., Btu/hr.ft^2.oF:',
     *		T45, F9.2)

	WRITE (*, 610) Q, AREA
 610	FORMAT (2X,'HEAT LOAD ON UNIT , Btu/hr.:', T45, F12.1,/,
     *		2X,'HEAT TRANSFER SURFACE, ft^2.:', T45, F8.3)

	ENDIF

	WRITE (*, 620)
 620	FORMAT (1H ,78(1H-))

	RETURN
	END      
