	PROGRAM PROG154

C	BY A.K. COKER
C	A.K.C. TECHNOLOGY 2015
C	U.K.

C	HEAT-TRACER REQUIREMENTS FOR PIPELINES.
C	THE PROGRAM CALCULATES THE HEAT LOSS AND TRACING REQUIREMENTS
C	FOR ANY GIVEN PIPELINE USING HOT OIL OR SOME OTHER HOT FLUID
C	MEDIUM AS THE HEAT SOURCE.  IT ALSO CALCULATES THE HEAT LOSS
C	FROM AN INSULATED PIPELINE WITHOUT A HEAT TRACER.

C	THIS PROGRAM WILL CALCULATE:
C	1.  SURFACE TEMPERATURE OF INSULATED TRACED PIPE.
C	2.  TOTAL HEAT TRANSFERRED PER 100 ft. OF PIPE.
C	3.  TOTAL HEAT TRANSFERRED FOR ENTIRE PIPELINE.
C	4.  FLOW RATE FOR HOT MEDIA.
C	5.  TOTAL NUMBER OF HEAT TRACERS REQUIRED WITH AND WITHOUT
C	    TRANSFER CEMENT.


C	HEAT TRANSFERRED THROUGH AN INSULATED PIPE ENCOUNTERS FOUR
C	RESISTANCES:

C	1.  FILM RESISTANCE ON THE INSIDE WALL OF THE PIPE.
C	2.  HEAT RESISTANCE THROUGH THE PIPE WALL.
C	3.  HEAT RESISTANCE THROUGH THE INSULATION.
C	4.  AIR-FILM RESISTANCE ON THE OUTSIDE OF THE INSULATION.
C
C	HOWEVER, THE FIRST TWO RESISTANCES, 1. AND 2. ARE NORMALLY
C	VERY SMALL AND ARE THEREFORE NEGLIGIBLE IN THIS PROGRAM.
C	***************************************************************
C	TMEDAV	= AVERAGE TEMPERATURE OF HOT MEDIUM, oF.
C	TMI	= HOT-MEDIUM INLET TEMPERATURE, oF.
C	TMO	= HOT-MEDIUM OUTLET TEMPERATURE, oF.
C	TAVG	= AVERAGE TEMPERATURE OF PIPE AND TRACER, oF.
C	DI	= INSIDE DIAMETER OF INSULATION, in.
C	OD	= OUTSIDE DIAMETER OF PIPE, in.
C	TAL	= ALLOWANCE FOR TRACER DIAMETER, in.
C	DOS	= OUTSIDE DIAMETER OF INSULATION, in.
C	TK	= INSULATION THICKNESS, in.
C	Q	= HEAT LOSS PER FOOT OF PIPE, Btu/h.ft.
C	KINS	= THERMAL CONDUCTIVITY OF INSULATION, Btu/h.ft^2.(oF/ft).
C	TS	= OUTSIDE SURFACE TEMPERATURE OF INSULATION, oF.
C	HA	= FILM HEAT-TRANSFER COEFFICIENT TO AIR CORRECTED
C		  FOR THE WIND, Btu/h.ft^2.oF.
C	TAIR	= AIR TEMPERATURE, oF.
C	HCOMB	= HC+HR: COMBINED CONVECTIVE AND RADIATIVE HEAT TRANSFER
C		  CO-EFFICIENT, Btu/h.ft^2.oF.
C	WF	= WIND FACTOR.
C	QT	= TOTAL HEAT LOSS FROM PIPELINE, Btu/h.
C	W	= FLOW RATE OF HOT MEDIUM, lb/h.
C	TOTL	= TOTAL PIPELINE LENGTH, ft.
C	CP	= SPECIFIC HEAT OF HOT MEDIUM, Btu/lb.oF.
C	TWOC	= NUMBER OF TRACERS REQUIRED WITHOUT HEAT-TRANSFER CEMENT.
C	TCA	= THERMAL CONDUCTANCE, TRACER TO PIPE
C		  WITHOUT CEMENT, Btu/h.oF(ft of pipe).
C	TWC	= NUMBER OF TRACERS REQUIRED WITH HEAT TRANSFER CEMENT.
C	TCB	= THERMAL CONDUCTANCE, TRACER TO PIPE
C		  WITH CEMENT, Btu/h.oF(ft of pipe).
C	TP	= TEMPERATURE IN THE PIPE, oF.
C	***************************************************************

	REAL OD, KINS


c	OPEN(UNIT=3,FILE='DATA154.DAT',STATUS='OLD',ACTION='READ',
c    *	ERR=18)

	OPEN (UNIT=3, FILE='DATA154.DAT',STATUS='OLD',ERR=18)



	OPEN (UNIT=1, FILE ='RES154.RES')

	PI = 3.1415927

C	READ THE TOTAL LENGTH OF PIPE, ft.: TOTL
C	READ THE TEMPERATURE IN THE PIPE, oF: TP
C	READ THE HOT-MEDIUM INLET TEMPERATURE, oF: TMI
C	READ THE HOT-MEDIUM OUTLET TEMPERATURE, oF: TMO
C	READ THE AIR TEMPERATURE, oF: TAIR
C	READ THE OUTSIDE DIAMETER OF PIPE, inch.: OD
C	READ THE ALLOWANCE FOR THE TRACER DIAMETER, inch.: TAL
C	READ THE INSULATION THICKNESS, inch.: TK
C	READ THE THERMAL CONDUCTIVITY OF INSULATION, Btu/h.ft^2(oF/ft): KINS
C	READ THE SPECIFIC HEAT CAPACITY OF THE HOT MEDIUM, Btu/lb.oF: CP
C	READ THE FILM HEAT TRANSFER COEFFICIENT TO AIR CORRECTED
C	FOR THE WIND, Btu/h .ft^2.oF: HA
C	READ THE THERMAL CONDUCTANCE, TRACER TO PIPE
C	WITHOUT CEMENT, Btu/h.oF (ft. of pipe).: TCA
C	READ THE THERMAL CONDUCTANCE, TRACER TO PIPE
C	WITH CEMENT, Btu/h.oF (ft. of pipe).: TCB


	READ (3, *, ERR=19) TOTL, TP, TMI
	READ (3, *, ERR=19) TMO, TAIR, OD
	READ (3, *, ERR=19) TAL, TK, KINS
	READ (3, *, ERR=19) CP, HA, TCA, TCB

	GO TO 20

 18	WRITE (*, 100)
 100	FORMAT (6X, 'DATA FILE DOES NOT EXIST')
	GO TO 999

 19	WRITE (*, 110)
 110	FORMAT (6X, 'ERROR MESSAGE IN THE DATA VALUE')
	GO TO 999


 20	WRITE (1, 120)
 120	FORMAT (///, 10X, 'HEAT TRACER REQUIREMENTS FOR PIPELINES AND ',
     *	/, 10X, 'HEAT LOSS FROM AN INSULATED PIPELINE WITH TRACING', /,
     *		78(1H*))

	WRITE ( 1, 130) TOTL, TP, TMI
 130	FORMAT (6X, 'TOTAL PIPELINE LENGTH, ft.:',T60,F9.1,/,
     *		6X, 'TEMPERATURE IN PIPE, oF:',T60,F9.1,/,
     *		6X, 'HOT-MEDIUM INLET TEMPERATURE, oF:',T60,F9.1)

	WRITE (1, 140) TMO, TAIR, OD
 140	FORMAT (6X, 'HOT MEDIUM OUTLET TEMPERATURE, oF:',T60, F9.1,/,
     *		6X, 'AIR TEMPERATURE, oF:',T60,F9.1,/,
     *		6X, 'OUTSIDE DIAMETER OF PIPE, in.:',T60,F9.3)

	WRITE (1, 150) TAL, TK, KINS
 150	FORMAT (6X, 'ALLOWANCE FOR TRACER DIAMETER, in.:', T60, F9.2,/,
     *		6X, 'INSULATION THICKNESS, in.:', T60, F9.2, /, 6X,
     *	 'THERMAL CONDUCTIVITY OF INSULATION, Btu/h.ft^2(oF/ft):', T60,
     *	 F9.3)

	WRITE (1, 160) CP, HA, TCA, TCB
 160	FORMAT (6X,'SPECIFIC HEAT OF HOT MEDIUM, Btu/Ib.oF:',T60,F9.3,
     *	/,6X,'FILM HEAT TRANSFER COEFFICIENT TO AIR',
     *	/,6X,'CORRECTED FOR WIND, Btu/ft^2.h.oF:',T60,F9.3,
     *	/,6X,'THERMAL CONDUCTANCE TRACER TO PIPE',
     *	/,6X,'WITHOUT CEMENT, Btu/h.oF.ft of pipe:',T60,F9.3
     *	/,6X,'THERMAL CONDUCTANCE TRACER TO PIPE',
     *	/,6X,'WITH CEMENT, Btu/h.oF.ft of pipe:',T60,F9.3)


	WRITE (*, 1000)
 1000	FORMAT (///, 10X, 'HEAT TRACER REQUIREMENTS FOR PIPELINES AND ',
     *	/, 10X, 'HEAT LOSS FROM AN INSULATED PIPELINE WITH TRACING', /,
     *		78(1H*))

	WRITE (*, 1100) TOTL, TP, TMI
 1100	FORMAT (6X, 'TOTAL PIPELINE LENGTH, ft.:',T60,F9.1,/,
     *		6X, 'TEMPERATURE IN PIPE, oF:',T60,F9.1,/,
     *		6X, 'HOT-MEDIUM INLET TEMPERATURE, oF:',T60,F9.1)

	WRITE (*, 1200) TMO, TAIR, OD
 1200	FORMAT (6X, 'HOT MEDIUM OUTLET TEMPERATURE, oF:',T60, F9.1,/,
     *		6X, 'AIR TEMPERATURE, oF:',T60,F9.1,/,
     *		6X, 'OUTSIDE DIAMETER OF PIPE, in.:',T60,F9.3)

        WRITE (*, 1300) TAL, TK, KINS
 1300	FORMAT (6X, 'ALLOWANCE FOR TRACER DIAMETER, in.:', T60, F9.2,/,
     *		6X, 'INSULATION THICKNESS, in.:', T60, F9.2, /, 6X,
     *	 'THERMAL CONDUCTIVITY OF INSULATION, Btu/h.ft^2(oF/ft):', T60,
     *	 F9.3)

	WRITE (*, 1400) CP, HA, TCA, TCB
 1400	FORMAT (6X,'SPECIFIC HEAT OF HOT MEDIUM, Btu/Ib.oF:',T60,F9.3,
     *	/,6X,'FILM HEAT TRANSFER COEFFICIENT TO AIR',
     *	/,6X,'CORRECTED FOR WIND, Btu/ft^2.h.oF:',T60,F9.3,
     *	/,6X,'THERMAL CONDUCTANCE TRACER TO PIPE',
     *	/,6X,'WITHOUT CEMENT, Btu/h.oF.ft of pipe:',T60,F9.3
     *	/,6X,'THERMAL CONDUCTANCE TRACER TO PIPE',
     *	/,6X,'WITH CEMENT, Btu/h.oF.ft of pipe:',T60,F9.3)


C	CALCULATE THE AVERAGE TEMPERATURE OF HOT MEDIUM, oF

	CONTRL = 0.0

 30	TMEDAV = 0.5*(TMI+TMO)
	TA = 0.5*(TMEDAV+TP)
	DI = OD+TAL
	DO = DI+2.0*TK
	HA1 = HA

 40	X = (ALOG(DO/DI)*HA1*DO)/(24.0*KINS)
	TS = (TA+X*TAIR)/(1.0+X)

	WRITE (1, 170) TS
 170	FORMAT (6X, 'OUTSIDE SURFACE TEMPERATURE OF INSULATION, oF:',
     *		T60,F9.3)

	WRITE (*, 1500) TS
 1500	FORMAT (6X, 'OUTSIDE SURFACE TEMPERATURE OF INSULATION, oF:',
     *		T60,F9.3)


C	CALCULATE THE COMBINED CONVECTIVE AND RADIATIVE HEAT TRANSFER
C	COEFFICIENT.

	HCOMB = 564.0/((DO**0.19)*(273.0-(TS-TAIR)))

	WRITE (1, 180) HCOMB
 180	FORMAT (6X,'THE COMBINED CONVECTIVE AND RADIATIVE', /, 6X,
     *	'HEAT TRANSFER COEFFICIENT, Btu/h.oF.ft^2:', T60, F9.3)


	WRITE (*, 1600) HCOMB
 1600	FORMAT (6X,'THE COMBINED CONVECTIVE AND RADIATIVE', /, 6X,
     *	'HEAT TRANSFER COEFFICIENT, Btu/h.oF.ft^2:', T60, F9.3)


C	CONSTANTS FOR THE WIND FACTOR

	C0 = 2.814
	C1 = -0.00038857
	C2 = -0.0000012857

	WF = C0+(C1*(TS-TAIR))+(C2*((TS-TAIR)**2))

C	CALCULATED FILM HEAT-TRANSFER COEFFICIENT TO AIR CORRECTED FOR
C	THE WIND, HA2: Btu/hr.ft^2.oF

	HA2 = HCOMB*WF

	IF ((HA2-HA1) .GE. 0.01) THEN
	HA1 = HA2
	GO TO 40
	ELSE

C	CALCULATE THE HEAT FLOW THROUGH THE INSULATION Btu/hr.(lin ft).

	QINS = (2.0*PI*KINS*(TA-TS))/(ALOG(DO/DI))

C	CALCULATE THE HEAT FLOW BY RADIATION AND CONVECTION TO AIR

	QRC = (HA1*PI*DO*(TS-TAIR))/12.0
	ENDIF

	WRITE (1, 190) WF, HA2
 190	FORMAT (6X,'WIND FACTOR:',T60, F9.3, /, 6X,
     *	'HEAT TRANSFER COEFFICIENT TO AIR', /, 6X,
     *	'CORRECTED FOR THE WIND, Btu/h.ft^2.oF:', T60, F9.3)


	WRITE (*, 1700) WF, HA2
 1700	FORMAT (6X,'WIND FACTOR:',T60, F9.3, /, 6X,
     *	'HEAT TRANSFER COEFFICIENT TO AIR', /, 6X,
     *	'CORRECTED FOR THE WIND, Btu/h.ft^2.oF:', T60, F9.3)


C	CALCULATE THE TOTAL HEAT LOST FROM PIPELINE ,Btu/hr.

	QT = QINS*TOTL

	WRITE (1, 200) QINS, QT
 200	FORMAT (6X,'HEAT LOSS PER FOOT OF PIPE, Btu/h.ft:', T60,F9.3,/,
     *	6X,'TOTAL HEAT LOSS FROM PIPELINE, Btu/h.:', T60, F9.3,/,
     *  78(1H-))



	WRITE (*, 1800) QINS, QT
 1800	FORMAT (6X,'HEAT LOSS PER FOOT OF PIPE, Btu/h.ft:', T60,F9.3,/,
     *	6X,'TOTAL HEAT LOSS FROM PIPELINE, Btu/h.:', T60, F9.3,/,
     *  78(1H-))




	IF (CONTRL .EQ. 1.0) THEN
	GO TO 999
	ELSE

C	CALCULATE THE FLOW RATE OF HOT MEDIUM, lb/h

	W = QT/(CP*(TMI-TMO))

	WRITE (1, 210) W
 210	FORMAT (6X,'FLOW RATE OF HOT MEDIUM, lb/h.:', T60, F9.3)


	WRITE (*, 1900) W
 1900	FORMAT (6X,'FLOW RATE OF HOT MEDIUM, lb/h.:', T60, F9.3)


C	CALCULATE THE NUMBER OF TRACERS REQUIRED WITHOUT
C	HEAT-TRANSFER CEMENT.

	TWOC = QINS/(TCA*(TMEDAV-TP))

C	CALCULATE THE NUMBER OF TRACERS REQUIRED WITH
C	HEAT-TRANSFER CEMENT.

	TWC = QINS/(TCB*(TMEDAV-TP))
	ENDIF


	WRITE (1, 220) TWOC, TWC
 220	FORMAT(6X,'THE NUMBER OF TRACERS WITHOUT HEAT TRANSFER CEMENT:',
     *	T60, F9.2,/,6X,
     *	'THE NUMBER OF TRACERS WITH HEAT TRANSFER CEMENT:',T60, F9.2)

	WRITE (1, 230)
 230	FORMAT (1H ,78(1H-))


	WRITE (*, 2000) TWOC, TWC
 2000	FORMAT(6X,'THE NUMBER OF TRACERS WITHOUT HEAT TRANSFER CEMENT:',
     *	T60, F9.2,/,6X,
     *	'THE NUMBER OF TRACERS WITH HEAT TRANSFER CEMENT:',T60, F9.2)


	WRITE (*, 2100)
 2100	FORMAT (1H ,78(1H-))

C	***************************************************************

C	CALCULATION OF HEAT LOSS FROM AN INSULATED PIPE WITHOUT
C	TRACING, WHERE TMI=TMO=TP, AND TA=0.0

	WRITE (1, 240)
 240	FORMAT (//, 6X,'HEAT LOSS FROM AN INSULATED PIPE',\)

	WRITE (1, 250)
 250	FORMAT (' WITHOUT TRACING', /1H ,78(1H*))

	WRITE (*, 2200)
 2200	FORMAT (//, 6X,'HEAT LOSS FROM AN INSULATED PIPE',\)


	WRITE (*, 2300)
 2300	FORMAT (' WITHOUT TRACING', /1H ,78(1H*))


C	TO CALCULATE THE HEAT LOSS FROM AN INSULATED PIPE, CONTRL=1.0

	TMI = TP
	TMO = TP
	TAL = 0.0
	CONTRL = CONTRL + 1.0
	GO TO 30

	CLOSE (3, STATUS='KEEP')
	CLOSE (1)

 999	STOP
	END
