	PROGRAM PROG15A

C	BY A.K. COKER
C	A.K.C. TECHNOLOGY
C	U.K. 2015


C	THIS PROGRAM CALCULATES THE CORRECTED L.M.T.D. IN SHELL-AND-TUBE
C	HEAT EXCHANGERS

C	THE PROGRAM CALCULATES:
C	1.  THE IDEAL AND TRUE MEAN TEMPERATURE DIFFERENCE FOR ONE
C	    OR MORE EXCHANGER IN SERIES.
C	2.  THE PROGRAM WILL INCREASE THE NUMBER OF EXCHANGER SHELL
C	    UNTIL A 'REASONABLE' F-FACTOR IS OBTAINED THUS ELIMINATING
C	    THE NEED FOR THE CHARTS AND GRAPHS NORMALLY USED TO CALCULATE
C	    F-FACTORS FOR SHELL-AND-TUBE HEAT EXCHANGERS.
C
C	    THE PROGRAM IS BASED ON THE FOLLOWING ASSUMPTIONS:
C
C	1.  THE HOT AND COLD FLUIDS FLOW COUNTERCURRENT TO EACH OTHER.
C	2.  THE OVERALL HEAT TRANSFER COEFFICIENT (U) IS CONSTANT
C	    THROUGHOUT THE HEAT EXCHANGER.
C	3.  THE FLOW RATE OF EACH FLUID IS CONSTANT.
C	4.  THE SPECIFIC HEAT OF EACH FLUID IS CONSTANT.
C	5.  THERE IS NO CONDENSATION OF VAPOR OR BOILING OF LIQUID
C	    IN ANY PART OF THE EXCHANGER.
C	6.  HEAT LOSSES ARE NEGLIGIBLE.
C	7.  THERE IS EQUAL HEAT TRANSFER SURFACE IN EACH PASS.
C	8.  THE TEMPERATURE OF THE SHELL-SIDE FLUID IN ANY SHELL-SIDE
C	    PASS IS UNIFORM OVER ANY CROSS-SECTION.
C
C	*****************************************************************
C	TH1	        = HOT FLUID INLET TEMPERATURE, oC.
C	TH2	        = HOT FLUID OUTLET TEMPERATURE, oC.
C	TC1	        = COLD FLUID INLET TEMPERATURE, oC.
C	TC2	        = COLD FLUID OUTLET TEMPERATURE, oC.
C	N	        = NUMBER OF SERIES EXCHANGER SHELLS REQUIRED.
C	LMTD	= LOG MEAN TEMPERATURE DIFFERENCE.
C	F	        = CORRECTION FACTOR.
C	DELT1	= TH2-TC1, oC.
C	DELT2	= TH1-TC2, oC.
C	DELT	        = LMTD.
C	*****************************************************************


	REAL LMTD, N

       OPEN(UNIT=3,FILE='DATA15S.DAT',STATUS='OLD',ERR=18)

c      OPEN(UNIT=3,FILE='DATA15.DAT',STATUS='OLD',ACTION='READ',ERR=18)
C	OPEN (UNIT=3, FILE='DATA15.DAT', STATUS='OLD', ERR=18)

	OPEN (UNIT=1, FILE='res15a.res')


C	READ THE HOT FLUID INLET TEMPERATURE, oC: TH1
C	READ THE HOT FLUID OUTLET TEMPERATURE, oC: TH2
C	READ THE COLD FLUID INLET TEMPERATURE, oC: TC1
C	READ THE COLD FLUID OUTLET TEMPERATURE, oC: TC2
C	READ THE INITIAL NUMBER OF SERIES EXCHANGER SHELLS REQUIRED: N

	READ (3, *, ERR=19) TH1, TH2
	READ (3, *, ERR=19) TC1, TC2
	READ (3, *, ERR=19) N
	GO TO 10

 18	WRITE (*, 100)
 100	FORMAT (6X, 'DATA FILE DOES NOT EXIST')
	GO TO 999

 19	WRITE (*, 110)
 110	FORMAT (6X, 'ERROR MESSAGE IN THE DATA VALUE')
	GO TO 999

c 10	WRITE (1, 115)
c 115	FORMAT (3X, 'TABLE 15-20',//)


 10	WRITE (1, 120)
 120	FORMAT (///,10X,'THE CORRECTED LMTD IN A SHELL AND TUBE HEAT',\)

	WRITE (1, 130)
 130	FORMAT (' EXCHANGER',/1H ,78(1H*))

C	WRITE (*, 118)
C118	FORMAT (3X,'TABLE 15-20',//)

	WRITE (*, 125)
 125	FORMAT (///,10X,'THE CORRECTED LMTD IN A SHELL AND TUBE HEAT',\)

	WRITE (*, 135)
 135	FORMAT (' EXCHANGER',/1H ,78(1H*))

	WRITE (1, 140) TH1, TH2
 140	FORMAT(6X,'HOT FLUID INLET TEMPERATURE, oC:', T60, F9.3,/,6X,
     *		'HOT FLUID OUTLET TEMPERATURE, oC:',T60, F9.3)

	WRITE (*, 145) TH1, TH2
 145	FORMAT(6X,'HOT FLUID INLET TEMPERATURE, oC:', T60, F9.3,/,6X,
     *		'HOT FLUID OUTLET TEMPERATURE, oC:',T60, F9.3)

	WRITE (1, 150) TC1, TC2
 150	FORMAT(6X,'COLD FLUID INLET TEMPERATURE, oC:',T60, F9.3,/,6X,
     *		'COLD FLUID OUTLET TEMPERATURE, oC:', T60, F9.3)

	WRITE (*, 155) TC1, TC2
 155	FORMAT(6X,'COLD FLUID INLET TEMPERATURE, oC:',T60, F9.3,/,6X,
     *		'COLD FLUID OUTLET TEMPERATURE, oC:', T60, F9.3)

	WRITE (1, 160) N
 160	FORMAT(6X,'NUMBER OF SERIES EXCHANGER SHELLS:',T60,F4.0)

	WRITE (*, 165) N
 165	FORMAT(6X,'NUMBER OF SERIES EXCHANGER SHELLS:',T60,F4.0)


	P = (TC2-TC1)/(TH1-TC1)
	R = (TH1-TH2)/(TC2-TC1)
	RSQRT = (R**2+1.)**0.5

 15	IF (R .EQ. 1.0) THEN
	GO TO 25
	ELSE
	VAL1 = 1.0-((P*R-1.0)/(P-1.0))**(1./N)
	VAL2 = R-((P*R-1.0)/(P-1.0))**(1./N)
	P1 = VAL1/VAL2
	ENDIF

	VAL3 = (2.0/P1)-1.0-R+RSQRT
	VAL4 = (2.0/P1)-1.0-R-RSQRT

	A = VAL3/VAL4

	IF ( A .LT. 0.0) THEN
	GO TO 30
	ELSE
	VAL5 = (RSQRT/(R-1.0))*ALOG((1.0-P1)/(1.0-P1*R))
	F = VAL5/ALOG(A)
	ENDIF

	GO TO 40

 30	N = N+1

	GO TO 15

 25	P2 = P/(N-P*(N-1.))
	VAL6 = (2.0/P2)-2.0+RSQRT
	VAL7 = (2.0/P2)-2.0-RSQRT
	B = VAL6/VAL7
	IF (B .LT. 0.0) THEN
	GO TO 30
	ELSE
	VAL8 = (RSQRT*P2)/(1.0-P2)
	F = VAL8/ALOG(B)
	ENDIF

 40	IF ( F .GT. 0.75) THEN
	GO TO 45
	ELSE
	N = N+1
	GO TO 15
	ENDIF

 45	DELT1 = TH1-TC2
	DELT2 = TH2-TC1
	IF (DELT1 .EQ. DELT2) THEN
	GO TO 50
	ELSE

C	CALCULATE THE LOG MEAN TEMPERATURE DIFFERENCE

	LMTD = (DELT1-DELT2)/ALOG(DELT1/DELT2)
	ENDIF
	GO TO 55

 50	DELT = LMTD

C	CALCULATE THE CORRECTED LOG MEAN TEMPERATURE DIFFERENCE

 55	CLMTD = F*LMTD

	WRITE (1, 168) P, R
 168	FORMAT (6X, 'THE PARAMETER P VALUE IS:', T60, F8.4,/,6X,
     *	'THE PARAMETER R VALUE IS:', T60, F8.4)

	WRITE (1, 170) N, F, LMTD, CLMTD
 170	FORMAT (6X,'THE NUMBER OF SHELLS REQUIRED:',T60, F4.0,/,6X,
     *	       'THE F- FACTOR:',T60, F8.4,/,6X,
     *	       'THE LOG MEAN TEMPERATURE DIFFERENCE,oC:',T60,F8.4,/,6X,
     *	       'THE CORRECTED LMTD, oC:',T60, F8.4)

	WRITE (*, 174) P, R
 174	FORMAT (6X, 'THE PARAMETER P VALUE IS:', T60, F8.4,/,6X,
     *	'THE PARAMETER R VALUE IS:', T60, F8.4)

	WRITE (*, 175) N, F, LMTD, CLMTD
 175	FORMAT (6X,'THE NUMBER OF SHELLS REQUIRED:',T60, F4.0,/,6X,
     *	       'THE F- FACTOR:',T60, F8.4,/,6X,
     *	       'THE LOG MEAN TEMPERATURE DIFFERENCE,oC:',T60,F8.4,/,6X,
     *	       'THE CORRECTED LMTD, oC:',T60, F8.4)

	WRITE (1, 180)
 180	FORMAT (1H ,78(1H-))

	WRITE (*, 185)
 185	FORMAT (1H ,78(1H-))

C	FORM FEED THE PRINTING PAPER TO TOP OF THE NEXT PAGE.

	WRITE (1, *) CHAR(12)

	CLOSE (3,STATUS='KEEP')
	CLOSE (1)
 999	STOP
	END
